@@ -27,7 +27,8 @@ class Attachment(AttachmentBase):
     def __init__(self, msg, dir_):
         """
         :param msg: the Message instance that the attachment belongs to.
-        :param dir_: the directory inside the msg file where the attachment is located.
+        :param dir_: the directory inside the msg file where the attachment is
+            located.
         """
         super().__init__(msg, dir_)
 
@@ -43,7 +44,7 @@ class Attachment(AttachmentBase):
             else:
                 self.__prefix = msg.prefixList + [dir_, '__substg1.0_3701000D']
                 self.__type = 'msg'
-                self.__data = openMsg(self.msg.path, self.__prefix, self.__class__, overrideEncoding = msg.overrideEncoding, attachmentErrorBehavior = msg.attachmentErrorBehavior, strict = False)
+                self.__data = openMsg(self.msg.path, prefix = self.__prefix, **self.msg.kwargs)
         elif (self.props['37050003'].value & 0x7) == 0x7:
             # TODO Handling for special attacment type 0x7
             self.__type = 'web'
@@ -211,35 +212,6 @@ class Attachment(AttachmentBase):
         """
         self.data.save(**kwargs)
 
-    @property
-    def attachmentEncoding(self):
-        """
-        The encoding information about the attachment object. Will return
-        b'*\x86H\x86\xf7\x14\x03\x0b\x01' if encoded in MacBinary format,
-        otherwise it is unset.
-        """
-        return self._ensureSet('_attachmentEncoding', '__substg1.0_37020102', False)
-
-    @property
-    def additionalInformation(self):
-        """
-        The additional information about the attachment. This property MUST be
-        an empty string if attachmentEncoding is not set. Otherwise it MUST be
-        set to a string of the format ":CREA:TYPE" where ":CREA" is the
-        four-letter Macintosh file creator code and ":TYPE" is a four-letter
-        Macintosh type code.
-        """
-        return self._ensureSet('_additionalInformation', '__substg1.0_370F')
-
-    @property
-    def cid(self):
-        """
-        Returns the Content ID of the attachment, if it exists.
-        """
-        return self._ensureSet('_cid', '__substg1.0_3712')
-
-    contendId = cid
-
     @property
     def data(self):
         """
@@ -247,13 +219,6 @@ class Attachment(AttachmentBase):
         """
         return self.__data
 
-    @property
-    def longFilename(self):
-        """
-        Returns the long file name of the attachment, if it exists.
-        """
-        return self._ensureSet('_longFilename', '__substg1.0_3707')
-
     @property
     def randomFilename(self):
         """
@@ -265,22 +230,6 @@ class Attachment(AttachmentBase):
             self.regenerateRandomName()
             return self.__randomName
 
-    @property
-    def renderingPosition(self):
-        """
-        The offset, in redered characters, to use when rendering the attachment
-        within the main message text. A value of 0xFFFFFFFF indicates a hidden
-        attachment that is not to be rendered.
-        """
-        return self._ensureSetProperty('_renderingPosition', '370B0003')
-
-    @property
-    def shortFilename(self):
-        """
-        Returns the short file name of the attachment, if it exists.
-        """
-        return self._ensureSet('_shortFilename', '__substg1.0_3704')
-
     @property
     def type(self):
         """
