@@ -40,27 +40,6 @@ RE_RTF_BODY_FALLBACK_F = re.compile(br'\\f[0-9]*[^a-zA-Z]')
 RE_RTF_FALLBACK_PLAIN = re.compile(br'\\plain[^a-zA-Z0-9]')
 
 
-# Constants used by named.py
-NUMERICAL_NAMED = 0
-STRING_NAMED = 1
-GUID_PS_MAPI = '{00020328-0000-0000-C000-000000000046}'
-GUID_PS_PUBLIC_STRINGS = '{00020329-0000-0000-C000-000000000046}'
-GUID_PSETID_COMMON = '{00062008-0000-0000-C000-000000000046}'
-GUID_PSETID_ADDRESS = '{00062004-0000-0000-C000-000000000046}'
-GUID_PS_INTERNET_HEADERS = '{00020386-0000-0000-C000-000000000046}'
-GUID_PSETID_APPOINTMENT = '{00062002-0000-0000-C000-000000000046}'
-GUID_PSETID_MEETING = '{6ED8DA90-450B-101B-98DA-00AA003F1305}'
-GUID_PSETID_LOG = '{0006200A-0000-0000-C000-000000000046}'
-GUID_PSETID_MESSAGING = '{41F28F13-83F4-4114-A584-EEDB5A6B0BFF}'
-GUID_PSETID_NOTE = '{0006200E-0000-0000-C000-000000000046}'
-GUID_PSETID_POSTRSS = '{00062041-0000-0000-C000-000000000046}'
-GUID_PSETID_TASK = '{00062003-0000-0000-C000-000000000046}'
-GUID_PSETID_UNIFIEDMESSAGING = '{4442858E-A9E3-4E80-B900-317A210CC15B}'
-GUID_PSETID_AIRSYNC = '{71035549-0739-4DCB-9163-00F0580DBBDF}'
-GUID_PSETID_SHARING = '{00062040-0000-0000-C000-000000000046}'
-GUID_PSETID_XMLEXTRACTEDENTITIES = '{23239608-685D-4732-9C55-4C95CB4E8E33}'
-GUID_PSETID_ATTACHMENT = '{96357F7F-59E1-47D0-99A7-46515C183B54}'
-
 # EntryID UID Types.
 EUID_PUBLIC_MESSAGE_STORE = b'\x1A\x44\x73\x90\xAA\x66\x11\xCD\x9B\xC8\x00\xAA\x00\x2F\xC4\x5A'
 EUID_PUBLIC_MESSAGE_STORE_HEX = '1A447390AA6611CD9BC800AA002FC45A'
@@ -548,71 +527,15 @@ CODE_PAGES = {
     65001: 'utf-8', # Unicode (UTF-8)
 }
 
-INTELLIGENCE_DUMB = 0
-INTELLIGENCE_SMART = 1
-INTELLIGENCE_TUPLE = (
-    'INTELLIGENCE_DUMB',
-    'INTELLIGENCE_SMART',
-)
-
-TYPE_MESSAGE = 0
-TYPE_MESSAGE_EMBED = 1
-TYPE_ATTACHMENT = 2
-TYPE_RECIPIENT = 3
-TYPE_TUPLE = (
-    'TYPE_MESSAGE',
-    'TYPE_MESSAGE_EMBED',
-    'TYPE_ATTACHMENT',
-    'TYPE_RECIPIENT',
-)
-
-RECIPIENT_SENDER = 0
-RECIPIENT_TO = 1
-RECIPIENT_CC = 2
-RECIPIENT_BCC = 3
-RECIPIENT_TUPLE = (
-    'RECIPIENT_SENDER',
-    'RECIPIENT_TO',
-    'RECIPIENT_CC',
-    'RECIPIENT_BCC',
-)
-
-# PidTagImportance
-IMPORTANCE_LOW = 0
-IMPORTANCE_MEDIUM = 1
-IMPORTANCE_HIGH = 2
-IMPORTANCE_TUPLE = (
-    'IMPORTANCE_LOW',
-    'IMPORTANCE_MEDIUM',
-    'IMPORTANCE_HIGH',
-)
-
-# PidTagSensitivity
-SENSITIVITY_NORMAL = 0
-SENSITIVITY_PERSONAL = 1
-SENSITIVITY_PRIVATE = 2
-SENSITIVITY_CONFIDENTIAL = 3
-SENSITIVITY_TUPLE = (
-    'SENSITIVITY_NORMAL',
-    'SENSITIVITY_PERSONAL',
-    'SENSITIVITY_PRIVATE',
-    'SENSITIVITY_CONFIDENTIAL',
-)
-
-# PidTagPriority
-PRIORITY_URGENT = 0x00000001
-PRIORITY_NORMAL = 0x00000000
-PRIORITY_NOT_URGENT = 0xFFFFFFFF
-
 PYTPFLOATINGTIME_START = datetime.datetime(1899, 12, 30)
 
 # Constants used for argparse stuff
-KNOWN_FILE_FLAGS = [
+KNOWN_FILE_FLAGS = (
     '--out-name',
-]
-NEEDS_ARG = [
+)
+NEEDS_ARG = (
     '--out-name',
-]
+)
 MAINDOC = "extract_msg:\n\tExtracts emails and attachments saved in Microsoft Outlook's .msg files.\n\n" \
           "https://github.com/TeamMsgExtractor/msg-extractor"
 
@@ -706,52 +629,10 @@ PTYPES = {
     0x1102: 'PtypMultipleBinary',
 }
 
-# Display types
-DT_MAILUSER = 0x0000
-DT_DISTLIST = 0x0001
-DT_FORUM = 0x0002
-DT_AGENT = 0x0003
-DT_ORGANIZATION = 0x0004
-DT_PRIVATE_DISTLIST = 0x0005
-DT_REMOTE_MAILUSER = 0x0006
-DT_CONTAINER = 0x0100
-DT_TEMPLATE = 0x0101
-DT_ADDRESS_TEMPLATE = 0x0102
-DT_SEARCH = 0x0200
-
-# Rule action types
-RA_OP_MOVE = 0x01
-RA_OP_COPY = 0x02
-RA_OP_REPLY = 0x03
-RA_OP_OOF_REPLY = 0x04
-RA_OP_DEFER_ACTION = 0x05
-RA_OP_BOUNCE = 0x06
-RA_OP_FORWARD = 0x07
-RA_OP_DELEGATE = 0x08
-RA_OP_TAG = 0x09
-RA_OP_DELETE = 0x0A
-RA_OP_MARK_AS_READ = 0x0B
-
-# Recipiet Row Flag Types
-RF_NOTYPE = 0x0
-RF_X500DN = 0x1
-RF_MSMAIL = 0x2
-RF_SMTP = 0x3
-RF_FAX = 0x4
-RF_PROFESSIONALOFFICESYSTEM = 0x5
-RF_PERSONALDESTRIBUTIONLIST1 = 0x6
-RF_PERSONALDESTRIBUTIONLIST2 = 0x7
-
-# Attachment Error behavior types
-ATTACHMENT_ERROR_THROW = 0
-ATTACHMENT_ERROR_NOT_IMPLEMENTED = 1
-ATTACHMENT_ERROR_BROKEN = 2
-
-
 # This property information was sourced from
 # http://www.fileformat.info/format/outlookmsg/index.htm
 # on 2013-07-22.
-# It was extended by The Elemental of Destruction on 2018-10-12
+# It was extended by The Elemental of Destruction on 2018-10-12.
 PROPERTIES = {
     '00010102': 'Template data',
     '0002000B': 'Alternate recipient allowed',
@@ -966,22 +847,3 @@ PROPERTIES = {
 
 
 # END CONSTANTS
-
-def int_to_data_type(integer):
-    """
-    Returns the name of the data type constant that has the value of :param integer:
-    """
-    return TYPE_TUPLE[integer]
-
-
-def int_to_intelligence(integer):
-    """
-    Returns the name of the intelligence level constant that has the value of :param integer:
-    """
-    return INTELLIGENCE_TUPLE[integer]
-
-def int_to_recipient_type(integer):
-    """
-    Returns the name of the recipient type constant that has the value of :param integer:
-    """
-    return RECIPIENT_TUPLE[integer]
