@@ -10,6 +10,7 @@ import RTFDE
 
 from . import constants
 from .attachment import Attachment, BrokenAttachment, UnsupportedAttachment
+from .enums import RecipientType
 from .exceptions import UnrecognizedMSGTypeError
 from .msg import MSGFile
 from .recipient import Recipient
@@ -25,9 +26,7 @@ class MessageBase(MSGFile):
     """
     Base class for Message like msg files.
     """
-    def __init__(self, path, prefix = '', attachmentClass = Attachment, filename = None,
-                 delayAttachments = False, overrideEncoding = None,
-                 attachmentErrorBehavior = constants.ATTACHMENT_ERROR_THROW, recipientSeparator = ';'):
+    def __init__(self, path, **kwargs):
         """
         :param path: path to the msg file in the system or is the raw msg file.
         :param prefix: used for extracting embeded msg files
@@ -46,23 +45,21 @@ class MessageBase(MSGFile):
         :param overrideEncoding: optional, an encoding to use instead of the one
             specified by the msg file. Do not report encoding errors caused by
             this.
-        :param attachmentErrorBehavior: Optional, the behaviour to use in the
+        :param attachmentErrorBehavior: Optional, the behavior to use in the
             event of an error when parsing the attachments.
         :param recipientSeparator: Optional, Separator string to use between
             recipients.
         """
-        super().__init__(path, prefix, attachmentClass, filename, overrideEncoding, attachmentErrorBehavior)
-        self.__attachmentsDelayed = delayAttachments
-        self.__attachmentsReady = False
-        self.__recipientSeparator = recipientSeparator
+        super().__init__(path, **kwargs)
+        recipientSeparator = ';'
+        self.__recipientSeparator = kwargs.get('recipientSeparator', ';')
         # Initialize properties in the order that is least likely to cause bugs.
         # TODO have each function check for initialization of needed data so these
         # lines will be unnecessary.
         self.mainProperties
         self.header
         self.recipients
-        if not delayAttachments:
-            self.attachments
+
         self.to
         self.cc
         self.sender
@@ -76,11 +73,12 @@ class MessageBase(MSGFile):
             logger.exception('Critical error accessing the body. File opened but accessing the body will throw an exception.')
         self.named
 
-    def _genRecipient(self, recipientType, recipientInt):
+    def _genRecipient(self, recipientType, recipientInt : RecipientType):
         """
         Returns the specified recipient field.
         """
         private = '_' + recipientType
+        recipientInt = RecipientType(recipientInt)
         try:
             return getattr(self, private)
         except AttributeError:
@@ -98,7 +96,7 @@ class MessageBase(MSGFile):
                     logger.info(f'Header found, but "{recipientType}" is not included. Will be generated from other streams.')
 
                 # Get a list of the recipients of the specified type.
-                foundRecipients = tuple(recipient.formatted for recipient in self.recipients if recipient.type & 0x0000000f == recipientInt)
+                foundRecipients = tuple(recipient.formatted for recipient in self.recipients if recipient.type == recipientInt)
 
                 # If we found recipients, join them with the recipient separator and a space.
                 if len(foundRecipients) > 0:
@@ -117,30 +115,6 @@ class MessageBase(MSGFile):
 
             return value
 
-    def _registerNamedProperty(self, entry, _type, name = None):
-        if self.attachmentsDelayed and not self.attachmentsReady:
-            try:
-                self.__waitingProperties
-            except AttributeError:
-                self.__waitingProperties = []
-            self.__waitingProperties.append((entry, _type, name))
-        else:
-            for attachment in self.attachments:
-                attachment._registerNamedProperty(entry, _type, name)
-
-        super()._registerNamedProperty(entry, _type, name)
-
-    def close(self) -> None:
-        try:
-            # If this throws an AttributeError then we have not loaded the attachments.
-            self._attachments
-            for attachment in self.attachments:
-                if attachment.type == 'msg':
-                    attachment.data.close()
-        except AttributeError:
-            pass
-        super().close()
-
     def headerInit(self) -> bool:
         """
         Checks whether the header has been initialized.
@@ -151,81 +125,12 @@ class MessageBase(MSGFile):
         except AttributeError:
             return False
 
-    def saveAttachments(self, **kwargs) -> None:
-        """
-        Saves only attachments in the same folder.
-        """
-        for attachment in self.attachments:
-            attachment.save(**kwargs)
-
-    @property
-    def attachments(self):
-        """
-        Returns a list of all attachments.
-        """
-        try:
-            return self._attachments
-        except AttributeError:
-            # Get the attachments
-            attachmentDirs = []
-            prefixLen = self.prefixLen
-            for dir_ in self.listDir(False, True):
-                if dir_[prefixLen].startswith('__attach') and\
-                        dir_[prefixLen] not in attachmentDirs:
-                    attachmentDirs.append(dir_[prefixLen])
-
-            self._attachments = []
-
-            for attachmentDir in attachmentDirs:
-                try:
-                    self._attachments.append(self.attachmentClass(self, attachmentDir))
-                except (NotImplementedError, UnrecognizedMSGTypeError) as e:
-                    if self.attachmentErrorBehavior > constants.ATTACHMENT_ERROR_THROW:
-                        logger.error(f'Error processing attachment at {attachmentDir}')
-                        logger.exception(e)
-                        self._attachments.append(UnsupportedAttachment(self, attachmentDir))
-                    else:
-                        raise
-                except Exception as e:
-                    if self.attachmentErrorBehavior == constants.ATTACHMENT_ERROR_BROKEN:
-                        logger.error(f'Error processing attachment at {attachmentDir}')
-                        logger.exception(e)
-                        self._attachments.append(BrokenAttachment(self, attachmentDir))
-                    else:
-                        raise
-
-            self.__attachmentsReady = True
-            try:
-                self.__waitingProperties
-                if self.__attachmentsDelayed:
-                    for attachment in self._attachments:
-                        for prop in self.__waitingProperties:
-                            attachment._registerNamedProperty(*prop)
-            except:
-                pass
-
-            return self._attachments
-
-    @property
-    def attachmentsDelayed(self):
-        """
-        Returns True if the attachment initialization was delayed.
-        """
-        return self.__attachmentsDelayed
-
-    @property
-    def attachmentsReady(self):
-        """
-        Returns True if the attachments are ready to be used.
-        """
-        return self.__attachmentsReady
-
     @property
     def bcc(self):
         """
         Returns the bcc field, if it exists.
         """
-        return self._genRecipient('bcc', 3)
+        return self._genRecipient('bcc', RecipientType.BCC)
 
     @property
     def body(self):
@@ -235,18 +140,20 @@ class MessageBase(MSGFile):
         try:
             return self._body
         except AttributeError:
-            self._body = self._getStringStream('__substg1.0_1000')
+            if self._ensureSet('_body', '__substg1.0_1000'):
+                pass
+            else:
+                # If the body doesn't exist, see if we can get it from the RTF
+                # body.
+                if self.deencapsulatedRtf and self.deencapsulatedRtf.content_type == 'text':
+                    self._body = self.deencapsulatedRtf.text
+
             if self._body:
                 self._body = inputToString(self._body, 'utf-8')
                 a = re.search('\n', self._body)
                 if a is not None:
                     if re.search('\r\n', self._body) is not None:
                         self.__crlf = '\r\n'
-            else:
-                # If the body doesn't exist, see if we can get it from the RTF
-                # body.
-                if self.deencapsulatedRtf and self.deencapsulatedRtf.content_type == 'text':
-                    self._body = self.deencapsulatedRtf.text
             return self._body
 
     @property
@@ -254,7 +161,7 @@ class MessageBase(MSGFile):
         """
         Returns the cc field, if it exists.
         """
-        return self._genRecipient('cc', 2)
+        return self._genRecipient('cc', RecipientType.CC)
 
     @property
     def compressedRtf(self):
@@ -534,4 +441,4 @@ class MessageBase(MSGFile):
         """
         Returns the to field, if it exists.
         """
-        return self._genRecipient('to', 1)
+        return self._genRecipient('to', RecipientType.TO)
