@@ -8,12 +8,13 @@ import zipfile
 import olefile
 
 from . import constants
-from .attachment import Attachment
+from .attachment import Attachment, BrokenAttachment, UnsupportedAttachment
+from .enums import AttachErrorBehavior, PropertiesType
+from .exceptions import InvalidFileFormatError, MissingEncodingError, UnrecognizedMSGTypeError
 from .named import Named
 from .prop import FixedLengthProp, VariableLengthProp
 from .properties import Properties
 from .utils import divide, getEncodingName, hasLen, inputToMsgpath, inputToString, msgpathToString, parseType, properHex, verifyPropertyId, verifyType, windowsUnicode
-from .exceptions import InvalidFileFormatError, MissingEncodingError
 
 
 logger = logging.getLogger(__name__)
@@ -21,9 +22,9 @@ logger.addHandler(logging.NullHandler())
 
 class MSGFile(olefile.OleFileIO):
     """
-    Parser for .msg files
+    Parser for .msg files.
     """
-    def __init__(self, path, prefix = '', attachmentClass = Attachment, filename = None, overrideEncoding = None, attachmentErrorBehavior = constants.ATTACHMENT_ERROR_THROW):
+    def __init__(self, path, **kwargs):
         """
         :param path: path to the msg file in the system or is the raw msg file.
         :param prefix: used for extracting embeded msg files
@@ -33,18 +34,36 @@ class MSGFile(olefile.OleFileIO):
             will use for attachments. You probably should
             not change this value unless you know what you
             are doing.
+        :param delayAttachments: optional, delays the initialization of
+            attachments until the user attempts to retrieve them. Allows MSG
+            files with bad attachments to be initialized so the other data can
+            be retrieved.
         :param filename: optional, the filename to be used by default when
             saving.
+        :param attachmentErrorBehavior: Optional, the behavior to use in the
+            event of an error when parsing the attachments.
         :param overrideEncoding: optional, an encoding to use instead of the one
             specified by the msg file. Do not report encoding errors caused by
             this.
+
+        :raises ValueError: If the attachment error behavior is not
+        :raises TypeError: If the prefix is not a supported type.
+
+        It's recommended to check the error message to ensure you know why a
+        specific exceptions was raised.
         """
+        # Retrieve all the kwargs that we need.
+        prefix = kwargs.get('prefix', '')
+        filename = kwargs.get('filename', None)
+        overrideEncoding = kwargs.get('overrideEncoding', None)
+
         # WARNING DO NOT MANUALLY MODIFY PREFIX. Let the program set it.
         self.__path = path
-        self.__attachmentClass = attachmentClass
-        if not (constants.ATTACHMENT_ERROR_THROW <= attachmentErrorBehavior <= constants.ATTACHMENT_ERROR_BROKEN):
-            raise ValueError(":param attachmentErrorBehavior: must be ATTACHMENT_ERROR_THROW, ATTACHMENT_ERROR_NOT_IMPLEMENTED, or ATTACHMENT_ERROR_BROKEN.")
-        self.__attachmentErrorBehavior = attachmentErrorBehavior
+        self.__attachmentClass = kwargs.get('attachmentClass', Attachment)
+        self.__attachmentsDelayed = kwargs.get('delayAttachments', False)
+        self.__attachmentsReady = False
+        self.__attachmentErrorBehavior = AttachErrorBehavior(kwargs.get('attachmentErrorBehavior', AttachErrorBehavior.THROW))
+        self.__waitingProperties = []
         if overrideEncoding is not None:
             codecs.lookup(overrideEncoding)
             logger.warning('You have chosen to override the string encoding. Do not report encoding errors caused by this.')
@@ -62,16 +81,21 @@ class MSGFile(olefile.OleFileIO):
             else:
                 raise
 
+        kwargsCopy = copy.copy(kwargs)
+        if 'prefix' in kwargsCopy:
+            del kwargsCopy['prefix']
+        self.__kwargs = kwargsCopy
+
         prefixl = []
         if prefix:
             try:
                 prefix = inputToString(prefix, 'utf-8')
-            except:
+            except Exception:
                 try:
                     prefix = '/'.join(prefix)
-                except:
-                    raise TypeError('Invalid prefix type: ' + str(type(prefix)) +
-                                    '\n(This was probably caused by you setting it manually).')
+                except Exception:
+                    raise TypeError(f'Invalid prefix type: {type(prefix)}\n' +
+                                    '(This was probably caused by you setting it manually).')
             prefix = prefix.replace('\\', '/')
             g = prefix.split('/')
             if g[-1] == '':
@@ -247,6 +271,8 @@ class MSGFile(olefile.OleFileIO):
         for x in (filename + _type,) if _type is not None else self.slistDir():
             if x.startswith(filename) and x.find('-') == -1:
                 contents = self._getStream(x, False)
+                if contents is None:
+                    continue
                 if len(contents) == 0:
                     return True, None # We found the file, but it was empty.
                 extras = []
@@ -259,7 +285,7 @@ class MSGFile(olefile.OleFileIO):
                     elif _type in ('1002', '1003', '1004', '1005', '1007', '1014', '1040', '1048'):
                         try:
                             streams = self.mainProperties[x[-8:]].realLength
-                        except:
+                        except Exception:
                             logger.error(f'Could not find matching VariableLengthProp for stream {x}')
                             streams = len(contents) // (2 if _type in constants.MULTIPLE_2_BYTES else 4 if _type in constants.MULTIPLE_4_BYTES else 8 if _type in constants.MULTIPLE_8_BYTES else 16)
                     else:
@@ -279,10 +305,27 @@ class MSGFile(olefile.OleFileIO):
         """
         FOR INTERNAL USE ONLY! DO NOT CALL MANUALLY!
 
-        Function to allow things like attachments in subclasses to have their
+        Function to allow types in subclasses to have their
         own named properties.
         """
-        pass
+        if not self.attachmentsReady:
+            self.__waitingProperties.append((entry, _type, name))
+        else:
+            # We specifically access internall to ensure that we get the
+            # local attachments and not some other type.
+            for attachment in self._attachments:
+                attachment._registerNamedProperty(entry, _type, name)
+
+    def close(self) -> None:
+        try:
+            # If this throws an AttributeError then we have not loaded the attachments.
+            self._attachments
+            for attachment in self.attachments:
+                if attachment.type == 'msg':
+                    attachment.data.close()
+        except AttributeError:
+            pass
+        super().close()
 
     def debug(self) -> None:
         for dir_ in self.listDir():
@@ -295,7 +338,7 @@ class MSGFile(olefile.OleFileIO):
         Checks if :param inp: exists in the msg file.
         """
         inp = self.fixPath(inp, prefix)
-        return olefile.OleFileIO.exists(self, inp)
+        return super().exists(inp)
 
     def sExists(self, inp, prefix : bool = True) -> bool:
         """
@@ -381,12 +424,19 @@ class MSGFile(olefile.OleFileIO):
     def save(self, *args, **kwargs):
         raise NotImplementedError(f'Saving is not yet supported for the {self.__class__.__name__} class.')
 
+    def saveAttachments(self, **kwargs) -> None:
+        """
+        Saves only attachments in the same folder.
+        """
+        for attachment in self.attachments:
+            attachment.save(**kwargs)
+
     def saveRaw(self, path):
-        # Create a 'raw' folder
+        # Create a 'raw' folder.
         path = pathlib.Path(path)
-        # Make the location
+        # Make the location.
         os.makedirs(path, exist_ok = True)
-        # Create the zipfile
+        # Create the zipfile.
         path /= 'raw.zip'
         if path.exists():
             raise FileExistsError(f'File "{path}" already exists.')
@@ -398,13 +448,13 @@ class MSGFile(olefile.OleFileIO):
                 if constants.PROPERTIES.get(code):
                     sysdir += ' - ' + constants.PROPERTIES[code]
 
-                # Generate appropriate filename
+                # Generate appropriate filename.
                 if dir_[-1].endswith('001E') or dir_[-1].endswith('001F'):
                     filename = 'contents.txt'
                 else:
                     filename = 'contents.bin'
 
-                # Save contents of directory
+                # Save contents of directory.
                 with zfile.open(sysdir + '/' + filename, 'w') as f:
                     data = self._getStream(dir_)
                     # Specifically check for None. If this is bytes we still want to do this line.
@@ -428,6 +478,54 @@ class MSGFile(olefile.OleFileIO):
             self.__bStringsUnicode = False
             return self.__bStringsUnicode
 
+    @property
+    def attachments(self):
+        """
+        Returns a list of all attachments.
+        """
+        try:
+            return self._attachments
+        except AttributeError:
+            # Get the attachments.
+            attachmentDirs = []
+            prefixLen = self.prefixLen
+            for dir_ in self.listDir(False, True):
+                if dir_[prefixLen].startswith('__attach') and \
+                        dir_[prefixLen] not in attachmentDirs:
+                    attachmentDirs.append(dir_[prefixLen])
+
+            self._attachments = []
+
+            for attachmentDir in attachmentDirs:
+                try:
+                    self._attachments.append(self.attachmentClass(self, attachmentDir))
+                except (NotImplementedError, UnrecognizedMSGTypeError) as e:
+                    if self.attachmentErrorBehavior != AttachErrorBehavior.THROW:
+                        logger.error(f'Error processing attachment at {attachmentDir}')
+                        logger.exception(e)
+                        self._attachments.append(UnsupportedAttachment(self, attachmentDir))
+                    else:
+                        raise
+                except Exception as e:
+                    if self.attachmentErrorBehavior == AttachErrorBehavior.BROKEN:
+                        logger.error(f'Error processing attachment at {attachmentDir}')
+                        logger.exception(e)
+                        self._attachments.append(BrokenAttachment(self, attachmentDir))
+                    else:
+                        raise
+
+            self.__attachmentsReady = True
+            try:
+                if self.__attachmentsDelayed:
+                    for attachment in self._attachments:
+                        for prop in self.__waitingProperties:
+                            attachment._registerNamedProperty(*prop)
+            except Exception as e:
+                logger.error('Error occured handling attachment named properties (msg.py).')
+                logger.exception(e)
+
+            return self._attachments
+
     @property
     def attachmentClass(self):
         """
@@ -437,7 +535,14 @@ class MSGFile(olefile.OleFileIO):
         return self.__attachmentClass
 
     @property
-    def attachmentErrorBehavior(self):
+    def attachmentsDelayed(self) -> bool:
+        """
+        Returns True if the attachment initialization was delayed.
+        """
+        return self.__attachmentsDelayed
+
+    @property
+    def attachmentErrorBehavior(self) -> AttachErrorBehavior:
         """
         The behavior to follow when an attachment raises an exception. Will be
         one of the following values:
@@ -448,19 +553,34 @@ class MSGFile(olefile.OleFileIO):
         return self.__attachmentErrorBehavior
 
     @property
-    def classType(self):
+    def attachmentsReady(self) -> bool:
+        """
+        Returns True if the attachments are ready to be used.
+        """
+        return self.__attachmentsReady
+
+    @property
+    def classType(self) -> str:
         """
         The class type of the MSG file.
         """
         return self._ensureSet('_classType', '__substg1.0_001A')
 
     @property
-    def importance(self):
+    def importance(self) -> int:
         """
         The specified importance of the msg file.
         """
         return self._ensureSetProperty('_importance', '00170003')
 
+    @property
+    def kwargs(self) -> dict:
+        """
+        The kwargs used to initialize this message, excluding the prefix. This
+        is used for initializing embedded msg files.
+        """
+        return self.__kwargs
+
     @property
     def mainProperties(self) -> Properties:
         """
@@ -470,7 +590,7 @@ class MSGFile(olefile.OleFileIO):
             return self._prop
         except AttributeError:
             self._prop = Properties(self._getStream('__properties_version1.0'),
-                                    constants.TYPE_MESSAGE if self.prefix == '' else constants.TYPE_MESSAGE_EMBED)
+                                    PropertiesType.MESSAGE if self.prefix == '' else PropertiesType.MESSAGE_EMBED)
             return self._prop
 
     @property
@@ -508,7 +628,7 @@ class MSGFile(olefile.OleFileIO):
         return self.__prefix
 
     @property
-    def prefixLen(self):
+    def prefixLen(self) -> int:
         """
         Returns the number of elements in the prefix.
         """
@@ -523,14 +643,14 @@ class MSGFile(olefile.OleFileIO):
         return copy.deepcopy(self.__prefixList)
 
     @property
-    def priority(self):
+    def priority(self) -> int:
         """
         The specified priority of the msg file.
         """
         return self._ensureSetProperty('_priority', '00260003')
 
     @property
-    def sensitivity(self):
+    def sensitivity(self) -> int:
         """
         The specified sensitivity of the msg file.
         """
@@ -541,7 +661,7 @@ class MSGFile(olefile.OleFileIO):
         try:
             return self.__stringEncoding
         except AttributeError:
-            # We need to calculate the encoding
+            # We need to calculate the encoding.
             # Let's first check if the encoding will be unicode:
             if self.areStringsUnicode:
                 self.__stringEncoding = "utf-16-le"
@@ -549,8 +669,12 @@ class MSGFile(olefile.OleFileIO):
             else:
                 # Well, it's not unicode. Now we have to figure out what it IS.
                 if not self.mainProperties.has_key('3FFD0003'):
-                    raise MissingEncodingError('Encoding property not found')
-                enc = self.mainProperties['3FFD0003'].value
-                # Now we just need to translate that value
-                self.__stringEncoding = getEncodingName(enc)
+                    # If this property is not set by the client, we SHOULD set
+                    # it to ISO-8859-15, but MAY set it to ISO-8859-1.
+                    logger.warn('Encoding property not found. Defaulting to ISO-8859-15.')
+                    self.__stringEncoding = 'iso-8859-15'
+                else:
+                    enc = self.mainProperties['3FFD0003'].value
+                    # Now we just need to translate that value.
+                    self.__stringEncoding = getEncodingName(enc)
                 return self.__stringEncoding
