@@ -3,6 +3,7 @@ import logging
 import pprint
 
 from . import constants
+from .enums import Guid, NamedPropertyType
 from .utils import bytesToGuid, divide, properHex, roundUp
 from compressed_rtf.crc32 import crc32
 
@@ -22,7 +23,7 @@ class Named:
         guidStreamLength = len(guidStream)
         entryStreamLength = len(entryStream)
         namesStreamLength = len(namesStream)
-        guids = tuple([None, constants.GUID_PS_MAPI, constants.GUID_PS_PUBLIC_STRINGS] + [bytesToGuid(x) for x in divide(guidStream, 16)])
+        guids = tuple([None, Guid.PS_MAPI.value, Guid.PS_PUBLIC_STRINGS.value] + [bytesToGuid(x) for x in divide(guidStream, 16)])
         entries = []
         for rawStream in divide(entryStream, 8):
             tmp = constants.STNP_ENT.unpack(rawStream)
@@ -30,7 +31,7 @@ class Named:
                 'id': tmp[0],
                 'pid': tmp[2],
                 'guid_index': tmp[1] >> 1,
-                'pkind': tmp[1] & 1, # 0 if numerical, 1 if string
+                'pkind': NamedPropertyType(tmp[1] & 1), # 0 if numerical, 1 if string.
                 'rawStream': rawStream,
                 }
             entry['guid'] = guids[entry['guid_index']]
@@ -51,9 +52,9 @@ class Named:
         self.__properties = []
         for entry in entries:
             streamID = properHex(0x8000 + entry['pid'])
-            msg._registerNamedProperty(entry, entry['pkind'], names[entry['id']] if entry['pkind'] == constants.STRING_NAMED else None)
+            msg._registerNamedProperty(entry, entry['pkind'], names[entry['id']] if entry['pkind'] == NamedPropertyType.STRING_NAMED else None)
             if msg.existsTypedProperty(streamID):
-                self.__properties.append(StringNamedProperty(entry, names[entry['id']], msg._getTypedData(streamID)) if entry['pkind'] == constants.STRING_NAMED else NumericalNamedProperty(entry, msg._getTypedData(streamID)))
+                self.__properties.append(StringNamedProperty(entry, names[entry['id']], msg._getTypedData(streamID)) if entry['pkind'] == NamedPropertyType.STRING_NAMED else NumericalNamedProperty(entry, msg._getTypedData(streamID)))
         self.__propertiesDict = {}
         for property in self.__properties:
             self.__propertiesDict[property.name if isinstance(property, StringNamedProperty) else property.propertyID] = property
@@ -148,14 +149,15 @@ class NamedAttachmentProperties:
         streamID = properHex(0x8000 + entry['pid']).upper()
         if self.__attachment.existsTypedProperty(streamID)[0]:
             data = self.__attachment._getTypedData(streamID)
-            property = StringNamedProperty(entry, name, data) if _type == constants.STRING_NAMED else NumericalNamedProperty(entry, data)
+            property = StringNamedProperty(entry, name, data) if NamedPropertyType(_type) == NamedPropertyType.STRING_NAMED else NumericalNamedProperty(entry, data)
             self.__properties.append(property)
             self.__propertiesDict[property.name if isinstance(property, StringNamedProperty) else property.propertyID] = property
 
     @property
     def attachment(self):
         """
-        The attachment that this NamedAttachmentProperties instance is associated with.
+        The attachment that this NamedAttachmentProperties instance is
+        associated with.
         """
         return self.__attachment
 
@@ -186,7 +188,7 @@ class StringNamedProperty:
         # generated by certain versions of Outlook. As such, a little bit of
         # additional code will need to run to determine exactly what the stream
         # ID should be if it is in that property set.
-        if self.__guid == constants.GUID_PS_INTERNET_HEADERS:
+        if self.__guid == Guid.PS_INTERNET_HEADERS.value:
             # To be sure if it needs to be lower the most effective method would
             # be to just get the Stream ID and then check if the entry is in
             # there. If it isn't, then check the regular case and see. If it is
@@ -242,7 +244,7 @@ class StringNamedProperty:
     @property
     def streamID(self):
         """
-        Returns the streamID of the named property. This may not be accurate
+        Returns the streamID of the named property. This may not be accurate.
         """
         return self.__streamID
 
@@ -251,7 +253,7 @@ class StringNamedProperty:
         """
         Returns the type of the named property. This will either be NUMERICAL_NAMED or STRING_NAMED.
         """
-        return constants.STRING_NAMED
+        return NamedPropertyType.STRING_NAMED
 
 
 
@@ -305,4 +307,4 @@ class NumericalNamedProperty:
         """
         Returns the type of the named property. This will either be NUMERICAL_NAMED or STRING_NAMED.
         """
-        return constants.NUMERICAL_NAMED
+        return NamedPropertyType.NUMERICAL_NAMED
